﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Shapes;
using Write_erase.Classes;

namespace Write_erase.UserPages
{
    /// <summary>
    /// Логика взаимодействия для BasketWindow.xaml
    /// </summary>
    public partial class BasketWindow : Window
    {
        public ObservableCollection<Product> BacketProducts = new ObservableCollection<Product>();
        public User NowUser;
        public double TotalCost;
        public BasketWindow(ObservableCollection<Product> backetUser)
        {
            InitializeComponent();
            NowUser = new User();
            BacketProducts = backetUser;
            if (string.IsNullOrWhiteSpace(NowUser.UserName) || string.IsNullOrWhiteSpace(NowUser.UserSurname))
                TB_FIO.Text = "";
            else
                TB_FIO.Text = NowUser.UserSurname + " " + NowUser.UserName[0] + ". " + NowUser.UserPatronymic[0] + ".";

            LVBasket.ItemsSource = BacketProducts;
            CB_PickupPoint.ItemsSource = DataBaseClass.entity.PickupPoint.Select(x => x.Adress).ToList();

            TotalCost = 0;
            foreach (Product product in BacketProducts)
            {
                if (product.ProductDiscountAmount != null)
                    TotalCost += Convert.ToDouble(product.CostD) * product.CountProduct;
                else
                    TotalCost += Convert.ToDouble(product.ProductCost) * product.CountProduct;
            }
            TB_TotalCost.Text = TotalCost.ToString("C2");
        }
        public BasketWindow(ObservableCollection<Product> backetUser, User user)
        {
            InitializeComponent();
            NowUser = user;
            BacketProducts = backetUser;
            if (string.IsNullOrWhiteSpace(NowUser.UserName) || string.IsNullOrWhiteSpace(NowUser.UserSurname))
                TB_FIO.Text = "";
            else
                TB_FIO.Text = NowUser.UserSurname + " " + NowUser.UserName[0] + ". " + NowUser.UserPatronymic[0] + ".";

            LVBasket.ItemsSource = BacketProducts;
            CB_PickupPoint.ItemsSource = DataBaseClass.entity.PickupPoint.Select(x => x.Adress).ToList();

            TotalCost = 0;
            foreach (Product product in BacketProducts)
            {
                if (product.ProductDiscountAmount != null)
                    TotalCost += Convert.ToDouble(product.CostD) * product.CountProduct;
                else
                    TotalCost += Convert.ToDouble(product.ProductCost) * product.CountProduct;
            }
            TB_TotalCost.Text = TotalCost.ToString("C2");
        }
        private void ToBack(object sender, RoutedEventArgs e)
        {
            this.Close();
        }

        private void ToOrder(object sender, RoutedEventArgs e)
        {
            int counDay = 6;
            DateTime dateDelivery;
            OrderProduct op;

            foreach (var x in BacketProducts)
            {
                if (x.ProductQuantityInStock <= 3)
                {
                    counDay = 3;
                    break;
                }
            }

            try
            {
                Order newOrder = new Order()
                {
                    OrderStatus = 1,
                    OrderCreateDate = DateTime.Now,
                    OrderDeliveryDate = DateTime.Now.AddDays(counDay),
                    OrderPickupPoint = DataBaseClass.entity.PickupPoint.FirstOrDefault(x => x.Adress == CB_PickupPoint.SelectedValue.ToString()).ID,
                    OrderClient = TB_FIO.Text,
                    OrderCode = new Random().Next(100, 1000)
                };

                DataBaseClass.entity.Order.Add(newOrder);
                DataBaseClass.entity.SaveChanges();

                foreach (var x in BacketProducts)
                {
                    op = new OrderProduct()
                    {
                        OrderID = newOrder.OrderID,
                        ProductArticleNumber = x.ProductArticleNumber,
                        ProductCount = x.CountProduct
                    };
                    DataBaseClass.entity.OrderProduct.Add(op);
                    x.CountProduct = 0;
                }
                DataBaseClass.entity.SaveChanges();
                BacketProducts.Clear();
                TotalCost = 0;
                foreach (Product product in BacketProducts)
                {
                    if (product.ProductDiscountAmount != null)
                        TotalCost += Convert.ToDouble(product.CostD) * product.CountProduct;
                    else
                        TotalCost += Convert.ToDouble(product.ProductCost) * product.CountProduct;
                }
                TB_TotalCost.Text = TotalCost.ToString("C2");
                MessageBox.Show("Зaказ принят", "Оформелние");
            }
            catch
            {
                MessageBox.Show("Зaказ не принят", "Ошибка");
            }

        }

        private void ChangetCount(object sender, RoutedEventArgs e)
        {
            Button btn = (Button)sender;
            Product thisProduct = BacketProducts.FirstOrDefault(x => x.ProductArticleNumber == btn.Uid);

            if (btn.Content.ToString() == "+" && thisProduct != null)
            {
                thisProduct.CountProduct++;
            }
            if (btn.Content.ToString() == "-" && thisProduct != null)
            {
                thisProduct.CountProduct--;

                if (thisProduct.CountProduct == 0)
                {
                    BacketProducts.Remove(thisProduct);
                    thisProduct.CountProduct = 0;
                }
            }
            TotalCost = 0;
            foreach (Product product in BacketProducts)
            {
                if (product.ProductDiscountAmount != null)
                    TotalCost += Convert.ToDouble(product.CostD) * product.CountProduct;
                else
                    TotalCost += Convert.ToDouble(product.ProductCost) * product.CountProduct;
            }
            TB_TotalCost.Text = TotalCost.ToString("C2");
        }

        private void DeleteItemFromOrder(object sender, RoutedEventArgs e)
        {
            BacketProducts.First(x => x.ProductArticleNumber == ((Button)sender).Uid).CountProduct = 0;
            BacketProducts.Remove(BacketProducts.First(x => x.ProductArticleNumber == ((Button)sender).Uid));
            TotalCost = 0;
            foreach (Product product in BacketProducts)
            {
                if (product.ProductDiscountAmount != null)
                    TotalCost += Convert.ToDouble(product.CostD) * product.CountProduct;
                else
                    TotalCost += Convert.ToDouble(product.ProductCost) * product.CountProduct;
            }
            TB_TotalCost.Text = TotalCost.ToString("C2");
        }
    }
}
